"use strict";

exports.__esModule = true;
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _lodash = _interopRequireDefault(require("lodash"));
var _moment = _interopRequireDefault(require("moment"));
var _Dropdown = _interopRequireDefault(require("./Dropdown"));
var _Grid = _interopRequireDefault(require("./Grid"));
var _Cell = _interopRequireDefault(require("./Cell"));
var _Responsive = require("./Responsive");
var _Visibility = _interopRequireDefault(require("./Visibility"));
var _CheckboxOnly = _interopRequireDefault(require("./CheckboxOnly"));
var _InputOnly = _interopRequireDefault(require("./InputOnly"));
var _ThrottledTextInput = _interopRequireDefault(require("./ThrottledTextInput"));
var _Icon = _interopRequireDefault(require("./Icon"));
var _Text = _interopRequireDefault(require("./Text"));
var _Spacing = _interopRequireDefault(require("./Spacing"));
var _SummaryItem = _interopRequireDefault(require("./SummaryItem"));
var _withStyles = require("../helpers/withStyles");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; _setPrototypeOf(subClass, superClass); }
function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }
var propTypes = {
  data: _propTypes.default.array.isRequired,
  loading: _propTypes.default.bool,
  dateFormat: _propTypes.default.string,
  divided: _propTypes.default.bool,
  searchPlaceholder: _propTypes.default.string,
  maxResults: _propTypes.default.number,
  noResultComponent: _propTypes.default.object,
  customActions: _propTypes.default.any,
  sortOptions: _propTypes.default.arrayOf(_propTypes.default.objectOf(_propTypes.default.string)),
  filterFor: _propTypes.default.arrayOf(_propTypes.default.oneOf(['title', 'description'])),
  clean: _propTypes.default.bool,
  onItemAction: _propTypes.default.func,
  paginate: _propTypes.default.bool,
  icons: _propTypes.default.arrayOf(_propTypes.default.string),
  withFilter: _propTypes.default.bool,
  sortable: _propTypes.default.bool,
  selectableItems: _propTypes.default.bool,
  hideComboButton: _propTypes.default.bool
};
var defaultProps = {
  data: [],
  dateFormat: 'YYYY-MM-DD hh:mm:ss',
  maxResults: 0,
  noResultComponent: /*#__PURE__*/_react.default.createElement(_Text.default, null, "Nenhum resultado..."),
  searchPlaceholder: 'buscar...',
  sortOptions: [{
    label: 'Data de criação',
    value: 'createdAt'
  }, {
    label: 'Última atualização',
    value: 'updatedAt'
  }, {
    label: 'Título',
    value: 'title'
  }],
  filterFor: ['title', 'description']
};
var SummaryList = /*#__PURE__*/function (_Component) {
  _inheritsLoose(SummaryList, _Component);
  function SummaryList(props) {
    var _this;
    _this = _Component.call(this, props) || this;
    _this.state = {
      checked: [],
      sort: props.sortOptions ? props.sortOptions[0] : null,
      filterString: ''
    };
    return _this;
  }
  var _proto = SummaryList.prototype;
  _proto.filterList = function filterList(data) {
    var _this$props = this.props,
      filterFor = _this$props.filterFor,
      withFilter = _this$props.withFilter;
    var filterString = this.state.filterString;
    if (withFilter && Array.isArray(filterFor) && filterFor.length > 0 && filterString.length > 2) {
      return data.filter(function (item) {
        return filterFor.some(function (filter) {
          try {
            return item[filter].toLowerCase().search(filterString.toLowerCase()) !== -1;
          } catch (e) {
            return false;
          }
        });
      });
    }
    return data;
  };
  _proto.sortList = function sortList(data) {
    var _this2 = this;
    var sort = this.state.sort;
    if (sort.value && data && Array.isArray(data) && data.length > 0 && data[0][sort.value] != null) {
      var isTime = (0, _moment.default)(data[0][sort.value], this.props.dateFormat).isValid();
      return _lodash.default.orderBy(data, function (item) {
        return isTime ? (0, _moment.default)(item[sort.value], _this2.props.dateFormat).valueOf() : item[sort.value];
      }, isTime ? ['desc'] : ['asc']);
    }
    return data;
  };
  _proto.toggleItem = function toggleItem(id) {
    var checked = [].concat(this.state.checked);
    if (checked.includes(id)) {
      checked.splice(id, 1);
    } else {
      checked.push(id);
    }
    this.setState({
      checked: checked
    });
  };
  _proto.render = function render() {
    var _this3 = this;
    var _this$props2 = this.props,
      data = _this$props2.data,
      loading = _this$props2.loading,
      divided = _this$props2.divided,
      searchPlaceholder = _this$props2.searchPlaceholder,
      noResultComponent = _this$props2.noResultComponent,
      maxResults = _this$props2.maxResults,
      customActions = _this$props2.customActions,
      sortOptions = _this$props2.sortOptions,
      clean = _this$props2.clean,
      paginate = _this$props2.paginate,
      onItemAction = _this$props2.onItemAction,
      icons = _this$props2.icons,
      withFilter = _this$props2.withFilter,
      selectableItems = _this$props2.selectableItems,
      sortable = _this$props2.sortable,
      styles = _this$props2.styles,
      css = _this$props2.css,
      hideComboButton = _this$props2.hideComboButton;
    var checked = this.state.checked;
    var listPlaceholder = loading ? /*#__PURE__*/_react.default.createElement(_react.Fragment, null, [].concat(Array(maxResults ? maxResults : 10)).map(function (e, i) {
      return /*#__PURE__*/_react.default.createElement(_SummaryItem.default, {
        divided: divided,
        key: i,
        loading: true
      });
    })) : /*#__PURE__*/_react.default.createElement("div", null, noResultComponent);
    return /*#__PURE__*/_react.default.createElement("div", css(styles.summaryList, clean && styles.summaryList_clean, checked.length > 0 && styles.summaryList_edit), (withFilter || sortable || selectableItems) && /*#__PURE__*/_react.default.createElement("div", css(styles.summaryList__header), /*#__PURE__*/_react.default.createElement(_Grid.default, {
      resetSpacing: true
    }, selectableItems && /*#__PURE__*/_react.default.createElement(_Cell.default, {
      shrink: true
    }, /*#__PURE__*/_react.default.createElement(_CheckboxOnly.default, null)), withFilter && /*#__PURE__*/_react.default.createElement(_Responsive.Responsive, {
      showFor: "large"
    }, /*#__PURE__*/_react.default.createElement(_Cell.default, {
      auto: true
    }, /*#__PURE__*/_react.default.createElement("div", css(styles.summaryList__header__filter), /*#__PURE__*/_react.default.createElement(_ThrottledTextInput.default, {
      debouncedOnChange: function debouncedOnChange(value) {
        return _this3.setState({
          filterString: value
        });
      },
      debounceTimeoutMs: 500
    }, /*#__PURE__*/_react.default.createElement(_InputOnly.default, {
      name: "filterInput",
      placeholder: searchPlaceholder,
      shimmer: loading,
      prefix: /*#__PURE__*/_react.default.createElement(_Icon.default, {
        name: "search"
      }),
      removeMargins: true
    }))))), customActions && /*#__PURE__*/_react.default.createElement(_Responsive.Responsive, {
      showFor: "large"
    }, /*#__PURE__*/_react.default.createElement(_Cell.default, {
      shrink: true
    }, customActions)), sortable && /*#__PURE__*/_react.default.createElement(_Cell.default, {
      shrink: true
    }, /*#__PURE__*/_react.default.createElement("span", null, /*#__PURE__*/_react.default.createElement(_Text.default, {
      small: true,
      inline: true,
      loading: loading
    }, "Ordernar por:"), /*#__PURE__*/_react.default.createElement(_Spacing.default, {
      left: .1,
      inline: true
    }, /*#__PURE__*/_react.default.createElement(_Dropdown.default, {
      button: true,
      label: this.state.sort && this.state.sort.label,
      options: sortOptions,
      onSelectOption: function onSelectOption(value) {
        return _this3.setState({
          sort: value
        });
      },
      shimmer: loading,
      loading: loading,
      closeOnSelect: true,
      inverse: true,
      compact: true,
      noSpacing: true
    })))))), /*#__PURE__*/_react.default.createElement("ul", css(styles.summaryList__list), data.length < 1 ? listPlaceholder : this.sortList(this.filterList(data)).map(function (item) {
      if (item) {
        return /*#__PURE__*/_react.default.createElement(_SummaryItem.default, {
          key: item.id,
          item: loading ? {} : item,
          clean: clean,
          divided: divided,
          checked: checked.includes(item.id),
          onAction: function onAction(action) {
            return onItemAction(action, item.id);
          },
          onChange: function onChange() {
            return _this3.toggleItem(item.id);
          },
          loading: loading,
          selectable: selectableItems,
          hideComboButton: hideComboButton
        }, /*#__PURE__*/_react.default.createElement(_react.Fragment, null, item.custom, icons && !item.custom ? /*#__PURE__*/_react.default.createElement(_react.Fragment, null, item.icons.map(function (icon) {
          return /*#__PURE__*/_react.default.createElement("i", {
            className: "icon-" + icon,
            key: icon
          });
        })) : null));
      } else {
        return false;
      }
    })), /*#__PURE__*/_react.default.createElement(_Visibility.default, {
      unmount: true,
      showIf: paginate
    }, "pagina\xE7\xE3o"));
  };
  return SummaryList;
}(_react.Component);
SummaryList.propTypes = propTypes;
SummaryList.defaultProps = defaultProps;
var SummaryListWithStyles = (0, _withStyles.withStyles)(function (_ref) {
  var _summaryList_clean;
  var units = _ref.units,
    color = _ref.color,
    breakpoint = _ref.breakpoint;
  return {
    summaryList: {},
    summaryList_clean: (_summaryList_clean = {}, _summaryList_clean[breakpoint.mediumAndAbove] = {
      //paddingLeft: units(2),
      //paddingRight: units(2),
    }, _summaryList_clean),
    summaryList_edit: {},
    summaryList__header: {
      paddingTop: 0,
      paddingBottom: units(1.5),
      borderBottomWidth: 1,
      borderBottomStyle: 'solid',
      borderBottomColor: color.blueGrayLight
    },
    summaryList__header__filter: {
      maxWidth: units(24)
    },
    summaryList__list: {
      margin: 0,
      padding: 0,
      listStyle: 'none'
    }
  };
})(SummaryList);
var _default = SummaryListWithStyles;
exports.default = _default;